@@ -68,7 +68,7 @@ sub chunked {
 # returns arrayref
 sub excludes {
     my $self = shift;
-    return $self->{excludes_aref};    
+    return [ @{ $self->{excludes_aref} } ];
 }
 
 sub _trim {
